@@ -1,7 +1,13 @@
 import requests
-import pkg_resources
 
-from py_clob_client.clob_types import FilterParams, TradeNotificationParams
+from py_clob_client.clob_types import (
+    DropNotificationParams,
+    BalanceAllowanceParams,
+    OrderScoringParams,
+    OrdersScoringParams,
+    TradeParams,
+    OpenOrderParams,
+)
 
 from ..exceptions import PolyApiException
 
@@ -63,7 +69,9 @@ def build_query_params(url: str, param: str, val: str) -> str:
     return url_with_params
 
 
-def add_query_params(base_url: str, params: FilterParams = None) -> str:
+def add_query_trade_params(
+    base_url: str, params: TradeParams = None, next_cursor="MA=="
+) -> str:
     """
     Adds query parameters to a url
     """
@@ -72,25 +80,23 @@ def add_query_params(base_url: str, params: FilterParams = None) -> str:
         url = url + "?"
         if params.market:
             url = build_query_params(url, "market", params.market)
-        if params.limit:
-            url = build_query_params(url, "limit", params.limit)
+        if params.asset_id:
+            url = build_query_params(url, "asset_id", params.asset_id)
         if params.after:
             url = build_query_params(url, "after", params.after)
         if params.before:
             url = build_query_params(url, "before", params.before)
-        if params.maker:
-            url = build_query_params(url, "maker", params.maker)
-        if params.taker:
-            url = build_query_params(url, "taker", params.taker)
+        if params.maker_address:
+            url = build_query_params(url, "maker_address", params.maker_address)
         if params.id:
             url = build_query_params(url, "id", params.id)
-        if params.owner:
-            url = build_query_params(url, "owner", params.owner)
+        if next_cursor:
+            url = build_query_params(url, "next_cursor", next_cursor)
     return url
 
 
-def add_trade_notifications_query_params(
-    base_url: str, params: TradeNotificationParams = None
+def add_query_open_orders_params(
+    base_url: str, params: OpenOrderParams = None, next_cursor="MA=="
 ) -> str:
     """
     Adds query parameters to a url
@@ -98,6 +104,72 @@ def add_trade_notifications_query_params(
     url = base_url
     if params:
         url = url + "?"
-        if params.index:
-            url = build_query_params(url, "index", params.index)
+        if params.market:
+            url = build_query_params(url, "market", params.market)
+        if params.asset_id:
+            url = build_query_params(url, "asset_id", params.asset_id)
+        if params.id:
+            url = build_query_params(url, "id", params.id)
+        if next_cursor:
+            url = build_query_params(url, "next_cursor", next_cursor)
+    return url
+
+
+def drop_notifications_query_params(
+    base_url: str, params: DropNotificationParams = None
+) -> str:
+    """
+    Adds query parameters to a url
+    """
+    url = base_url
+    if params:
+        url = url + "?"
+        if params.ids:
+            url = build_query_params(url, "ids", ",".join(params.ids))
+    return url
+
+
+def add_balance_allowance_params_to_url(
+    base_url: str, params: BalanceAllowanceParams = None
+) -> str:
+    """
+    Adds query parameters to a url
+    """
+    url = base_url
+    if params:
+        url = url + "?"
+        if params.asset_type:
+            url = build_query_params(url, "asset_type", params.asset_type.__str__())
+        if params.token_id:
+            url = build_query_params(url, "token_id", params.token_id)
+        if params.signature_type is not None:
+            url = build_query_params(url, "signature_type", params.signature_type)
+    return url
+
+
+def add_order_scoring_params_to_url(
+    base_url: str, params: OrderScoringParams = None
+) -> str:
+    """
+    Adds query parameters to a url
+    """
+    url = base_url
+    if params:
+        url = url + "?"
+        if params.orderId:
+            url = build_query_params(url, "order_id", params.orderId)
+    return url
+
+
+def add_orders_scoring_params_to_url(
+    base_url: str, params: OrdersScoringParams = None
+) -> str:
+    """
+    Adds query parameters to a url
+    """
+    url = base_url
+    if params:
+        url = url + "?"
+        if params.orderIds:
+            url = build_query_params(url, "order_ids", ",".join(params.orderIds))
     return url
