@@ -1,7 +1,6 @@
 import hashlib
-import json
 
-from .clob_types import OrderBookSummary, OrderSummary
+from .clob_types import OrderBookSummary, OrderSummary, TickSize
 
 
 def parse_raw_orderbook_summary(raw_obs: any) -> OrderBookSummary:
@@ -29,3 +28,15 @@ def generate_orderbook_summary_hash(orderbook: OrderBookSummary) -> str:
     hash = hashlib.sha1(str(orderbook.json).encode("utf-8")).hexdigest()
     orderbook.hash = hash
     return hash
+
+
+def order_to_json(order, owner, orderType) -> dict:
+    return {"order": order.dict(), "owner": owner, "orderType": orderType}
+
+
+def is_tick_size_smaller(a: TickSize, b: TickSize) -> bool:
+    return float(a) < float(b)
+
+
+def price_valid(price: float, tick_size: TickSize) -> bool:
+    return price >= float(tick_size) and price <= 1 - float(tick_size)
